@@ -1,8 +1,9 @@
 from unittest import TestCase
 from os.path import dirname, realpath
-from fil_io.json import load_single
 from os import getcwd, chdir
 
+from testing import load_json_file
+
 
 class TestAPIValidation(TestCase):
     def test_basic_with_schema_file(self):
@@ -13,7 +14,7 @@ class TestAPIValidation(TestCase):
         api_schema_file = (
             f"{dirname(realpath(__file__))}/test_data/api/test_request_resource.json"
         )
-        api_data = load_single(
+        api_data = load_json_file(
             f"{dirname(realpath(__file__))}/test_data/api/request_basic.json"
         )
         APIDataValidator(
@@ -26,7 +27,7 @@ class TestAPIValidation(TestCase):
         )
 
         api_schema_file = f"{dirname(realpath(__file__))}/test_data/api/test_request_resource-POST.json"
-        api_data = load_single(
+        api_data = load_json_file(
             f"{dirname(realpath(__file__))}/test_data/api/request_basic.json"
         )
         APIDataValidator(
@@ -39,7 +40,7 @@ class TestAPIValidation(TestCase):
         )
 
         api_schema_directory = f"{dirname(realpath(__file__))}/test_data/api/"
-        api_data = load_single(
+        api_data = load_json_file(
             f"{dirname(realpath(__file__))}/test_data/api/request_basic.json"
         )
 
@@ -62,7 +63,7 @@ class TestAPIValidation(TestCase):
             chdir(dirname(realpath(__file__)))
 
             api_schema_file = "./test_data/api/test_request_resource.json"
-            api_data = load_single("./test_data/api/request_basic.json")
+            api_data = load_json_file("./test_data/api/request_basic.json")
 
             APIDataValidator(
                 file=api_schema_file,
@@ -81,7 +82,7 @@ class TestAPIValidation(TestCase):
         try:
             chdir(dirname(realpath(__file__)))
             api_schema_directory = "./test_data/api/"
-            api_data = load_single("./test_data/api/request_basic.json")
+            api_data = load_json_file("./test_data/api/request_basic.json")
 
             def api_basic():
                 APIDataValidator(
@@ -102,7 +103,7 @@ class TestAPIValidation(TestCase):
         api_schema_file = (
             f"{dirname(realpath(__file__))}/test_data/api/test_request_resource.json"
         )
-        api_data = load_single(
+        api_data = load_json_file(
             f"{dirname(realpath(__file__))}/test_data/api/request_basic.json"
         )
         api_data["httpMethod"] = "WRONG"
@@ -131,7 +132,7 @@ class TestAPIValidation(TestCase):
         api_schema_file = (
             f"{dirname(realpath(__file__))}/test_data/api/test_request_resource.json"
         )
-        api_data = load_single(
+        api_data = load_json_file(
             f"{dirname(realpath(__file__))}/test_data/api/request_basic.json"
         )
         api_data["body"] = None
@@ -160,7 +161,7 @@ class TestAPIValidation(TestCase):
         api_schema_file = (
             f"{dirname(realpath(__file__))}/test_data/api/test_request_resource.json"
         )
-        api_data = load_single(
+        api_data = load_json_file(
             f"{dirname(realpath(__file__))}/test_data/api/request_basic.json"
         )
 
@@ -177,11 +178,11 @@ class TestAPIValidation(TestCase):
             {
                 "statusCode": 400,
                 "body": "123 is not of type 'string'\n\n"
-                "Failed validating 'type' in "
-                "schema['properties']['body']['properties']['body_key1']:\n"
-                "    {'description': 'containing only a string', 'type': 'string'}\n\n"
-                "On instance['body']['body_key1']:\n"
-                "    123",
+                        "Failed validating 'type' in "
+                        "schema['properties']['body']['properties']['body_key1']:\n"
+                        "    {'description': 'containing only a string', 'type': 'string'}\n\n"
+                        "On instance['body']['body_key1']:\n"
+                        "    123",
                 "headers": {"Content-Type": "text/plain"},
             },
             TE.exception.args[0],
@@ -195,7 +196,7 @@ class TestAPIValidation(TestCase):
         api_schema_file = (
             f"{dirname(realpath(__file__))}/test_data/api/test_request_resource.json"
         )
-        api_data = load_single(
+        api_data = load_json_file(
             f"{dirname(realpath(__file__))}/test_data/api/request_basic.json"
         )
         api_data.pop("pathParameters")
@@ -224,7 +225,7 @@ class TestAPIValidation(TestCase):
         api_schema_file = (
             f"{dirname(realpath(__file__))}/test_data/api/test_request_resource.json"
         )
-        api_data = load_single(
+        api_data = load_json_file(
             f"{dirname(realpath(__file__))}/test_data/api/request_aws_http_event.json"
         )
         APIDataValidator(
@@ -252,13 +253,12 @@ class TestAPIValidation(TestCase):
         )
 
         api_schema_directory = f"{dirname(realpath(__file__))}/test_data/api/"
-        api_data = {
-            "httpMethod": "POST",
-            "body": {"key_1": "some_string"}
-        }
+        api_data = {"httpMethod": "POST", "body": {"key_1": "some_string"}}
 
         APIDataValidator(
-            file=api_schema_directory, api_data=api_data, api_name="/test_request_resource/specific_resource"
+            file=api_schema_directory,
+            api_data=api_data,
+            api_name="/test_request_resource/specific_resource",
         )
 
     def test_url_nested_path_variables(self):
@@ -273,16 +273,18 @@ class TestAPIValidation(TestCase):
             "headers": {"content-type": "application/json"},
             "pathParameters": {
                 "path_level1": "path_value1",
-                "path_level2": "path_value"
+                "path_level2": "path_value",
             },
             "multiValueQueryStringParameters": {
                 "key1": ["some string"],
-                "key2": ["another string"]
-            }
+                "key2": ["another string"],
+            },
         }
 
         APIDataValidator(
-            file=api_schema_directory, api_data=api_data, api_name="/test_request_resource/{path_level1}/{path_level2}"
+            file=api_schema_directory,
+            api_data=api_data,
+            api_name="/test_request_resource/{path_level1}/{path_level2}",
         )
 
     def test_basic_with_parameter_casting(self):
@@ -290,10 +292,8 @@ class TestAPIValidation(TestCase):
             APIDataValidator,
         )
 
-        api_schema_file = (
-            f"{dirname(realpath(__file__))}/test_data/api/test_request_resource_parsing_params.json"
-        )
-        api_data = load_single(
+        api_schema_file = f"{dirname(realpath(__file__))}/test_data/api/test_request_resource_parsing_params.json"
+        api_data = load_json_file(
             f"{dirname(realpath(__file__))}/test_data/api/request_basic_for_parsing_params.json"
         )
         APIDataValidator(
@@ -305,10 +305,8 @@ class TestAPIValidation(TestCase):
             APIDataValidator,
         )
 
-        api_schema_file = (
-            f"{dirname(realpath(__file__))}/test_data/api/test_request_resource_parsing_params.json"
-        )
-        api_data = load_single(
+        api_schema_file = f"{dirname(realpath(__file__))}/test_data/api/test_request_resource_parsing_params.json"
+        api_data = load_json_file(
             f"{dirname(realpath(__file__))}/test_data/api/request_basic_for_parsing_params.json"
         )
 
@@ -340,10 +338,8 @@ class TestAPIValidation(TestCase):
             APIDataValidator,
         )
 
-        api_schema_file = (
-            f"{dirname(realpath(__file__))}/test_data/api/test_request_resource_parsing_params.json"
-        )
-        api_data = load_single(
+        api_schema_file = f"{dirname(realpath(__file__))}/test_data/api/test_request_resource_parsing_params.json"
+        api_data = load_json_file(
             f"{dirname(realpath(__file__))}/test_data/api/request_basic_for_parsing_params.json"
         )
 
@@ -371,10 +367,12 @@ class TestAPIValidation(TestCase):
         )
 
         api_schema_file = (
-            f"{dirname(realpath(__file__))}/test_data/api/test_request_resource_parsing_x_www_form_urlencoded_params-POST.json"
+                str(dirname(realpath(__file__))) +
+                "/test_data/api/test_request_resource_parsing_x_www_form_urlencoded_params-POST.json"
         )
-        api_data = load_single(
-            f"{dirname(realpath(__file__))}/test_data/api/request_resource_for_parsing_x_www_form_urlencoded_params.json"
+        api_data = load_json_file(
+            str(dirname(realpath(__file__))) +
+            "/test_data/api/request_resource_for_parsing_x_www_form_urlencoded_params.json"
         )
         parsed_data = APIDataValidator(
             file=api_schema_file, api_data=api_data, api_name="test_request_resource"
@@ -385,5 +383,5 @@ class TestAPIValidation(TestCase):
             "type_list_of_strings_key": [["abc", "0123"]],
             "type_object_key": [{"sub_key3.1": "02", "sub_key3.2": 2}],
             "type_list_of_numbers_key": [[2.34, 45.6]],
-            "double_query_key": [2, 4]
+            "double_query_key": [2, 4],
         }
