@@ -5,13 +5,8 @@ def test_response_translation_text_plain():
     open_api_response = {
         "description": "Response for statusCode '404' for method 'POST' on API 'response_test'",
         "content": {
-            "text/plain": {
-                "schema": {
-                    "type": "string",
-                    "example": "not found"
-                }
-            }
-        }
+            "text/plain": {"schema": {"type": "string", "example": "not found"}}
+        },
     }
 
     json_schema_response = {
@@ -21,37 +16,31 @@ def test_response_translation_text_plain():
         "type": "object",
         "additionalProperties": False,
         "properties": {
-            "statusCode": {
-                "type": "number"
-            },
-            "body": {
-                "type": "string",
-                "examples": [
-                    "not found"
-                ]
-            },
+            "statusCode": {"type": "number"},
+            "body": {"type": "string", "examples": ["not found"]},
             "headers": {
                 "type": "object",
-                "properties": {
-                    "content-type": {
-                        "type": "string",
-                        "enum": [
-                            "text/plain"
-                        ]
-                    }
-                }
-            }
+                "additionalProperties": True,
+                "patternProperties": {
+                    "[cC]ontent-[tT]ype": {"type": "string", "enum": ["text/plain"]}
+                },
+            },
         },
-        "required": [
-            "statusCode",
-            "headers",
-            "body"
-        ]
+        "required": ["statusCode", "headers", "body"],
     }
 
     from aws_schema.openAPI_converter import _convert_response
-    assert _convert_response(open_api_path, open_api_method, open_api_statusCode,
-                             open_api_response, {"info": dict()}) == json_schema_response
+
+    assert (
+        _convert_response(
+            open_api_path,
+            open_api_method,
+            open_api_statusCode,
+            open_api_response,
+            {"info": dict()},
+        )
+        == json_schema_response
+    )
 
 
 def test_response_translation_application_json():
@@ -65,69 +54,76 @@ def test_response_translation_application_json():
                 "schema": {
                     "type": "object",
                     "properties": {
-                        "key1": {
-                            "type": "string",
-                            "example": "some string"
-                        },
-                        "key2": {
-                            "type": "number",
-                            "example": 0.3
-                        },
-                        "key3": {
-                            "type": "integer",
-                            "examples": [1, 2, 3]
-                        },
+                        "key1": {"type": "string", "example": "some string"},
+                        "key2": {"type": "number", "example": 0.3},
+                        "key3": {"type": "integer", "examples": [1, 2, 3]},
                         "key4": {
                             "type": "array",
-                            "items": {
-                                "type": "string"
-                            },
-                            "example": ["a", "b"]
+                            "items": {"type": "string"},
+                            "example": ["a", "b"],
                         },
                         "key5": {
                             "type": "object",
-                            "properties": {
-                                "sub_key": {
-                                    "type": "string"
-                                }
-                            }
-                        }
-                    }
+                            "properties": {"sub_key": {"type": "string"}},
+                        },
+                    },
                 }
             }
-        }
+        },
     }
 
     json_schema_response = {
-        '$schema': 'http://json-schema.org/draft-07/schema#',
-        'additionalProperties': False,
-        'description': "Response for statusCode '200' for method 'POST' on API "
-                       "'response_test'",
-        'properties': {'body': {'properties': {'key1': {'examples': ['some string'],
-                                                        'type': 'string'},
-                                               'key2': {'examples': [0.3],
-                                                        'type': 'number'},
-                                               'key3': {'examples': [1, 2, 3],
-                                                        'type': 'integer'},
-                                               'key4': {'examples': [['a', 'b']],
-                                                        'items': {'type': 'string'},
-                                                        'type': 'array'},
-                                               'key5': {
-                                                   'properties': {'sub_key': {'type': 'string'}},
-                                                   'type': 'object'}},
-                                'type': 'object'},
-                       'headers': {'properties': {'content-type': {'enum': ['application/json'],
-                                                                   'type': 'string'}},
-                                   'type': 'object'},
-                       'statusCode': {'type': 'number'}},
-        'required': ['statusCode', 'headers', "body"],
-        'title': 'test_request_resource-POST-200',
-        'type': 'object'
+        "$schema": "http://json-schema.org/draft-07/schema#",
+        "additionalProperties": False,
+        "description": "Response for statusCode '200' for method 'POST' on API "
+        "'response_test'",
+        "properties": {
+            "body": {
+                "properties": {
+                    "key1": {"examples": ["some string"], "type": "string"},
+                    "key2": {"examples": [0.3], "type": "number"},
+                    "key3": {"examples": [1, 2, 3], "type": "integer"},
+                    "key4": {
+                        "examples": [["a", "b"]],
+                        "items": {"type": "string"},
+                        "type": "array",
+                    },
+                    "key5": {
+                        "properties": {"sub_key": {"type": "string"}},
+                        "type": "object",
+                    },
+                },
+                "type": "object",
+            },
+            "headers": {
+                "additionalProperties": True,
+                "patternProperties": {
+                    "[cC]ontent-[tT]ype": {
+                        "enum": ["application/json"],
+                        "type": "string",
+                    }
+                },
+                "type": "object",
+            },
+            "statusCode": {"type": "number"},
+        },
+        "required": ["statusCode", "headers", "body"],
+        "title": "test_request_resource-POST-200",
+        "type": "object",
     }
 
     from aws_schema.openAPI_converter import _convert_response
-    assert _convert_response(open_api_path, open_api_method, open_api_statusCode,
-                             open_api_response, {"info": dict()}) == json_schema_response
+
+    assert (
+        _convert_response(
+            open_api_path,
+            open_api_method,
+            open_api_statusCode,
+            open_api_response,
+            {"info": dict()},
+        )
+        == json_schema_response
+    )
 
 
 def test_response_translation_multiple_content_types():
@@ -137,55 +133,75 @@ def test_response_translation_multiple_content_types():
     open_api_response = {
         "description": "Response for statusCode '200' for method 'POST' on API 'response_test'",
         "content": {
-            "text/plain": {
-                "schema": {
-                    "type": "string",
-                    "example": "not found"
-                }
-            },
+            "text/plain": {"schema": {"type": "string", "example": "not found"}},
             "application/json": {
-                "schema": {
-                    "type": "object",
-                    "properties": {
-                        "key1": {
-                            "type": "string"
-                        }
-                    }
-                }
-            }
-        }
+                "schema": {"type": "object", "properties": {"key1": {"type": "string"}}}
+            },
+        },
     }
 
     json_schema_response = {
-        '$schema': 'http://json-schema.org/draft-07/schema#',
-        'description': "Response for statusCode '200' for method 'POST' on API "
-                       "'response_test'",
-        'oneOf': [{'additionalProperties': False,
-                   'properties': {'body': {'examples': ['not found'],
-                                           'type': 'string'},
-                                  'headers': {'properties': {'content-type': {'enum': ['text/plain',
-                                                                                       'application/json'],
-                                                                              'type': 'string'}},
-                                              'type': 'object'},
-                                  'statusCode': {'type': 'number'}},
-                   'required': ['statusCode', 'headers', "body"],
-                   'type': 'object'},
-                  {'additionalProperties': False,
-                   'properties': {'body': {'properties': {'key1': {'type': 'string'}},
-                                           'type': 'object'},
-                                  'headers': {'properties': {'content-type': {'enum': ['text/plain',
-                                                                                       'application/json'],
-                                                                              'type': 'string'}},
-                                              'type': 'object'},
-                                  'statusCode': {'type': 'number'}},
-                   'required': ['statusCode', 'headers', "body"],
-                   'type': 'object'}],
-        'title': 'test_request_resource-POST-200'
+        "$schema": "http://json-schema.org/draft-07/schema#",
+        "description": "Response for statusCode '200' for method 'POST' on API "
+        "'response_test'",
+        "oneOf": [
+            {
+                "additionalProperties": False,
+                "properties": {
+                    "body": {"examples": ["not found"], "type": "string"},
+                    "headers": {
+                        "additionalProperties": True,
+                        "patternProperties": {
+                            "[cC]ontent-[tT]ype": {
+                                "enum": ["text/plain", "application/json"],
+                                "type": "string",
+                            }
+                        },
+                        "type": "object",
+                    },
+                    "statusCode": {"type": "number"},
+                },
+                "required": ["statusCode", "headers", "body"],
+                "type": "object",
+            },
+            {
+                "additionalProperties": False,
+                "properties": {
+                    "body": {
+                        "properties": {"key1": {"type": "string"}},
+                        "type": "object",
+                    },
+                    "headers": {
+                        "additionalProperties": True,
+                        "patternProperties": {
+                            "[cC]ontent-[tT]ype": {
+                                "enum": ["text/plain", "application/json"],
+                                "type": "string",
+                            }
+                        },
+                        "type": "object",
+                    },
+                    "statusCode": {"type": "number"},
+                },
+                "required": ["statusCode", "headers", "body"],
+                "type": "object",
+            },
+        ],
+        "title": "test_request_resource-POST-200",
     }
 
     from aws_schema.openAPI_converter import _convert_response
-    assert _convert_response(open_api_path, open_api_method, open_api_statusCode,
-                             open_api_response, {"info": dict()}) == json_schema_response
+
+    assert (
+        _convert_response(
+            open_api_path,
+            open_api_method,
+            open_api_statusCode,
+            open_api_response,
+            {"info": dict()},
+        )
+        == json_schema_response
+    )
 
 
 def test_response_translation_additional_headers():
@@ -195,27 +211,15 @@ def test_response_translation_additional_headers():
     open_api_response = {
         "description": "Response for statusCode '404' for method 'POST' on API 'response_test'",
         "content": {
-            "text/plain": {
-                "schema": {
-                    "type": "string",
-                    "example": "not found"
-                }
-            }
+            "text/plain": {"schema": {"type": "string", "example": "not found"}}
         },
         "headers": {
             "header1": {
-                "schema": {
-                    "type": "integer"
-                },
-                "description": "some description"
+                "schema": {"type": "integer"},
+                "description": "some description",
             },
-            "header2": {
-                "schema": {
-                    "type": "string",
-                    "pattern": "regex"
-                }
-            }
-        }
+            "header2": {"schema": {"type": "string", "pattern": "regex"}},
+        },
     }
 
     json_schema_response = {
@@ -225,45 +229,39 @@ def test_response_translation_additional_headers():
         "type": "object",
         "additionalProperties": False,
         "properties": {
-            "statusCode": {
-                "type": "number"
-            },
-            "body": {
-                "type": "string",
-                "examples": [
-                    "not found"
-                ]
-            },
+            "statusCode": {"type": "number"},
+            "body": {"type": "string", "examples": ["not found"]},
             "headers": {
                 "type": "object",
+                "additionalProperties": True,
+                "patternProperties": {
+                    "[cC]ontent-[tT]ype": {"type": "string", "enum": ["text/plain"]}
+                },
                 "properties": {
-                    "content-type": {
-                        "type": "string",
-                        "enum": [
-                            "text/plain"
-                        ]
-                    },
-                    "header1": {
-                        "type": "integer",
-                        "description": "some description"
-                    },
-                    "header2": {
-                        "type": "string",
-                        "pattern": "regex"
-                    }
-                }
-            }
+                    "header1": {"type": "integer", "description": "some description"},
+                    "header2": {"type": "string", "pattern": "regex"},
+                },
+            },
         },
         "required": [
             "statusCode",
             "headers",
             "body",
-        ]
+        ],
     }
 
     from aws_schema.openAPI_converter import _convert_response
-    assert _convert_response(open_api_path, open_api_method, open_api_statusCode,
-                             open_api_response, {"info": dict()}) == json_schema_response
+
+    assert (
+        _convert_response(
+            open_api_path,
+            open_api_method,
+            open_api_statusCode,
+            open_api_response,
+            {"info": dict()},
+        )
+        == json_schema_response
+    )
 
 
 def test_response_translation_array():
@@ -281,18 +279,14 @@ def test_response_translation_array():
                             "type": "array",
                             "items": {
                                 "type": "object",
-                                "properties": {
-                                    "key1": {
-                                        "type": "string"
-                                    }
-                                },
-                                "required": ["key1"]
-                            }
+                                "properties": {"key1": {"type": "string"}},
+                                "required": ["key1"],
+                            },
                         }
-                    }
+                    },
                 }
             }
-        }
+        },
     }
 
     json_schema_response = {
@@ -302,9 +296,7 @@ def test_response_translation_array():
         "type": "object",
         "additionalProperties": False,
         "properties": {
-            "statusCode": {
-                "type": "number"
-            },
+            "statusCode": {"type": "number"},
             "body": {
                 "type": "object",
                 "properties": {
@@ -312,38 +304,38 @@ def test_response_translation_array():
                         "type": "array",
                         "items": {
                             "type": "object",
-                            "properties": {
-                                "key1": {
-                                    "type": "string"
-                                }
-                            },
-                            "required": ["key1"]
-                        }
+                            "properties": {"key1": {"type": "string"}},
+                            "required": ["key1"],
+                        },
                     }
-                }
+                },
             },
             "headers": {
                 "type": "object",
-                "properties": {
-                    "content-type": {
+                "additionalProperties": True,
+                "patternProperties": {
+                    "[cC]ontent-[tT]ype": {
                         "type": "string",
-                        "enum": [
-                            "application/json"
-                        ]
+                        "enum": ["application/json"],
                     }
-                }
-            }
+                },
+            },
         },
-        "required": [
-            "statusCode",
-            "headers",
-            "body"
-        ]
+        "required": ["statusCode", "headers", "body"],
     }
 
     from aws_schema.openAPI_converter import _convert_response
-    assert _convert_response(open_api_path, open_api_method, open_api_statusCode,
-                             open_api_response, {"info": dict()}) == json_schema_response
+
+    assert (
+        _convert_response(
+            open_api_path,
+            open_api_method,
+            open_api_statusCode,
+            open_api_response,
+            {"info": dict()},
+        )
+        == json_schema_response
+    )
 
 
 def test_response_translation_with_reference():
@@ -356,14 +348,12 @@ def test_response_translation_with_reference():
             "application/json": {
                 "schema": {
                     "type": "object",
-                    'properties': {
-                        "ref_key": {
-                            "$ref": "#/components/schemas/example_ref"
-                        }
-                    }
+                    "properties": {
+                        "ref_key": {"$ref": "#/components/schemas/example_ref"}
+                    },
                 }
             }
-        }
+        },
     }
 
     components = {
@@ -373,17 +363,15 @@ def test_response_translation_with_reference():
                 "example_ref": {
                     "type": "object",
                     "properties": {
-                        'example_key1': {
-                            'description': 'explaining example_key1',
-                            'type': 'string'
+                        "example_key1": {
+                            "description": "explaining example_key1",
+                            "type": "string",
                         },
-                        'example_key2': {
-                            'type': 'integer'
-                        }
-                    }
+                        "example_key2": {"type": "integer"},
+                    },
                 }
             }
-        }
+        },
     }
 
     json_schema_response = {
@@ -393,9 +381,7 @@ def test_response_translation_with_reference():
         "type": "object",
         "additionalProperties": False,
         "properties": {
-            "statusCode": {
-                "type": "number"
-            },
+            "statusCode": {"type": "number"},
             "body": {
                 "type": "object",
                 "properties": {
@@ -404,35 +390,43 @@ def test_response_translation_with_reference():
                         "properties": {
                             "example_key1": {
                                 "description": "explaining example_key1",
-                                "type": "string"
+                                "type": "string",
                             },
-                            "example_key2": {
-                                "type": "integer"
-                            }
-                        }
+                            "example_key2": {"type": "integer"},
+                        },
                     }
-                }
+                },
             },
             "headers": {
                 "type": "object",
-                "properties": {
-                    'content-type': {
-                        'enum': ['application/json'],
-                        'type': 'string'
+                "additionalProperties": True,
+                "patternProperties": {
+                    "[cC]ontent-[tT]ype": {
+                        "enum": ["application/json"],
+                        "type": "string",
                     }
-                }
-            }
+                },
+            },
         },
         "required": [
             "statusCode",
             "headers",
             "body",
-        ]
+        ],
     }
 
     from aws_schema.openAPI_converter import _convert_response
-    assert _convert_response(open_api_path, open_api_method, open_api_statusCode,
-                             open_api_response, components) == json_schema_response
+
+    assert (
+        _convert_response(
+            open_api_path,
+            open_api_method,
+            open_api_statusCode,
+            open_api_response,
+            components,
+        )
+        == json_schema_response
+    )
 
 
 def test_response_translation_with_reference_in_items():
@@ -448,14 +442,12 @@ def test_response_translation_with_reference_in_items():
                     "properties": {
                         "example_key": {
                             "type": "array",
-                            'items': {
-                                "$ref": "#/components/schemas/example_ref"
-                            }
+                            "items": {"$ref": "#/components/schemas/example_ref"},
                         }
-                    }
+                    },
                 }
             }
-        }
+        },
     }
 
     components = {
@@ -465,17 +457,15 @@ def test_response_translation_with_reference_in_items():
                 "example_ref": {
                     "type": "object",
                     "properties": {
-                        'example_key1': {
-                            'description': 'explaining example_key1',
-                            'type': 'string'
+                        "example_key1": {
+                            "description": "explaining example_key1",
+                            "type": "string",
                         },
-                        'example_key2': {
-                            'type': 'integer'
-                        }
-                    }
+                        "example_key2": {"type": "integer"},
+                    },
                 }
             }
-        }
+        },
     }
 
     json_schema_response = {
@@ -485,9 +475,7 @@ def test_response_translation_with_reference_in_items():
         "type": "object",
         "additionalProperties": False,
         "properties": {
-            "statusCode": {
-                "type": "number"
-            },
+            "statusCode": {"type": "number"},
             "body": {
                 "type": "object",
                 "properties": {
@@ -498,45 +486,51 @@ def test_response_translation_with_reference_in_items():
                             "properties": {
                                 "example_key1": {
                                     "description": "explaining example_key1",
-                                    "type": "string"
+                                    "type": "string",
                                 },
-                                "example_key2": {
-                                    "type": "integer"
-                                }
-                            }
-                        }
+                                "example_key2": {"type": "integer"},
+                            },
+                        },
                     }
-                }
+                },
             },
             "headers": {
                 "type": "object",
-                "properties": {
-                    'content-type': {
-                        'enum': ['application/json'],
-                        'type': 'string'
+                "additionalProperties": True,
+                "patternProperties": {
+                    "[cC]ontent-[tT]ype": {
+                        "enum": ["application/json"],
+                        "type": "string",
                     }
-                }
-            }
+                },
+            },
         },
         "required": [
             "statusCode",
             "headers",
             "body",
-        ]
+        ],
     }
 
     from aws_schema.openAPI_converter import _convert_response
-    assert _convert_response(open_api_path, open_api_method, open_api_statusCode,
-                             open_api_response, components) == json_schema_response
+
+    assert (
+        _convert_response(
+            open_api_path,
+            open_api_method,
+            open_api_statusCode,
+            open_api_response,
+            components,
+        )
+        == json_schema_response
+    )
 
 
 def test_response_translation_no_body():
     open_api_path = "test_path_with_ref"
     open_api_method = "post"
     open_api_statusCode = 404
-    open_api_response = {
-        "description": "not found"
-    }
+    open_api_response = {"description": "not found"}
 
     json_schema_response = {
         "$schema": "http://json-schema.org/draft-07/schema#",
@@ -545,21 +539,27 @@ def test_response_translation_no_body():
         "type": "object",
         "additionalProperties": False,
         "properties": {
-            "statusCode": {
-                "type": "number"
-            },
+            "statusCode": {"type": "number"},
             "headers": {
+                "additionalProperties": True,
                 "type": "object",
-            }
+            },
         },
-        "required": [
-            "statusCode"
-        ]
+        "required": ["statusCode"],
     }
 
     from aws_schema.openAPI_converter import _convert_response
-    assert _convert_response(open_api_path, open_api_method, open_api_statusCode,
-                             open_api_response, {"info": dict()}) == json_schema_response
+
+    assert (
+        _convert_response(
+            open_api_path,
+            open_api_method,
+            open_api_statusCode,
+            open_api_response,
+            {"info": dict()},
+        )
+        == json_schema_response
+    )
 
 
 def test_response_translation_no_body_with_header():
@@ -568,13 +568,7 @@ def test_response_translation_no_body_with_header():
     open_api_statusCode = 400
     open_api_response = {
         "description": "error",
-        "headers": {
-            "header_key": {
-                "schema": {
-                    "type": "string"
-                }
-            }
-        }
+        "headers": {"header_key": {"schema": {"type": "string"}}},
     }
 
     json_schema_response = {
@@ -584,27 +578,28 @@ def test_response_translation_no_body_with_header():
         "type": "object",
         "additionalProperties": False,
         "properties": {
-            "statusCode": {
-                "type": "number"
-            },
+            "statusCode": {"type": "number"},
             "headers": {
                 "type": "object",
-                "properties": {
-                    "header_key": {
-                        "type": "string"
-                    }
-                }
-            }
+                "additionalProperties": True,
+                "properties": {"header_key": {"type": "string"}},
+            },
         },
-        "required": [
-            "statusCode",
-            "headers"
-        ]
+        "required": ["statusCode", "headers"],
     }
 
     from aws_schema.openAPI_converter import _convert_response
-    assert _convert_response(open_api_path, open_api_method, open_api_statusCode,
-                             open_api_response, {"info": dict()}) == json_schema_response
+
+    assert (
+        _convert_response(
+            open_api_path,
+            open_api_method,
+            open_api_statusCode,
+            open_api_response,
+            {"info": dict()},
+        )
+        == json_schema_response
+    )
 
 
 def test_response_translation_text_plain_without_schema():
@@ -613,11 +608,7 @@ def test_response_translation_text_plain_without_schema():
     open_api_statusCode = 400
     open_api_response = {
         "description": "error",
-        "content": {
-            "text/plain": {
-            },
-            "example": "not found"
-        }
+        "content": {"text/plain": {}, "example": "not found"},
     }
 
     json_schema_response = {
@@ -627,33 +618,31 @@ def test_response_translation_text_plain_without_schema():
         "type": "object",
         "additionalProperties": False,
         "properties": {
-            "statusCode": {
-                "type": "number"
-            },
-            "body": {
-                "type": "string",
-                "example": "not found"
-            },
+            "statusCode": {"type": "number"},
+            "body": {"type": "string", "example": "not found"},
             "headers": {
                 "type": "object",
-                "properties": {
-                    'content-type': {
-                        'enum': ['text/plain'],
-                        'type': 'string'
-                    }
-                }
-            }
+                "additionalProperties": True,
+                "patternProperties": {
+                    "[cC]ontent-[tT]ype": {"enum": ["text/plain"], "type": "string"}
+                },
+            },
         },
-        "required": [
-            "statusCode",
-            "headers",
-            "body"
-        ]
+        "required": ["statusCode", "headers", "body"],
     }
 
     from aws_schema.openAPI_converter import _convert_response
-    assert _convert_response(open_api_path, open_api_method, open_api_statusCode,
-                             open_api_response, {"info": dict()}) == json_schema_response
+
+    assert (
+        _convert_response(
+            open_api_path,
+            open_api_method,
+            open_api_statusCode,
+            open_api_response,
+            {"info": dict()},
+        )
+        == json_schema_response
+    )
 
 
 def test_response_translation_propertyPattern():
@@ -666,14 +655,10 @@ def test_response_translation_propertyPattern():
             "application/json": {
                 "schema": {
                     "type": "object",
-                    "patternProperties": {
-                        "^\d+$": {
-                            "type": "string"
-                        }
-                    }
+                    "patternProperties": {"^\\d+$": {"type": "string"}},
                 }
             }
-        }
+        },
     }
 
     json_schema_response = {
@@ -683,40 +668,38 @@ def test_response_translation_propertyPattern():
         "type": "object",
         "additionalProperties": False,
         "properties": {
-            "statusCode": {
-                "type": "number"
-            },
+            "statusCode": {"type": "number"},
             "body": {
                 "type": "object",
-                "patternProperties": {
-                    "^\d+$": {
-                        "type": "string"
-                    }
-                },
-                "additionalProperties": False
+                "patternProperties": {"^\\d+$": {"type": "string"}},
+                "additionalProperties": False,
             },
             "headers": {
                 "type": "object",
-                "properties": {
-                    "content-type": {
+                "additionalProperties": True,
+                "patternProperties": {
+                    "[cC]ontent-[tT]ype": {
                         "type": "string",
-                        "enum": [
-                            "application/json"
-                        ]
+                        "enum": ["application/json"],
                     }
-                }
-            }
+                },
+            },
         },
-        "required": [
-            "statusCode",
-            "headers",
-            "body"
-        ]
+        "required": ["statusCode", "headers", "body"],
     }
 
     from aws_schema.openAPI_converter import _convert_response
-    assert _convert_response(open_api_path, open_api_method, open_api_statusCode,
-                             open_api_response, {"info": dict()}) == json_schema_response
+
+    assert (
+        _convert_response(
+            open_api_path,
+            open_api_method,
+            open_api_statusCode,
+            open_api_response,
+            {"info": dict()},
+        )
+        == json_schema_response
+    )
 
 
 def test_response_translation_propertyPattern_with_ref():
@@ -730,13 +713,11 @@ def test_response_translation_propertyPattern_with_ref():
                 "schema": {
                     "type": "object",
                     "patternProperties": {
-                        "^\d+$": {
-                            "$ref": "#/components/schemas/example_ref"
-                        }
-                    }
+                        "^\\d+$": {"$ref": "#/components/schemas/example_ref"}
+                    },
                 }
             }
-        }
+        },
     }
 
     components = {
@@ -746,17 +727,15 @@ def test_response_translation_propertyPattern_with_ref():
                 "example_ref": {
                     "type": "object",
                     "properties": {
-                        'example_key1': {
-                            'description': 'explaining example_key1',
-                            'type': 'string'
+                        "example_key1": {
+                            "description": "explaining example_key1",
+                            "type": "string",
                         },
-                        'example_key2': {
-                            'type': 'integer'
-                        }
-                    }
+                        "example_key2": {"type": "integer"},
+                    },
                 }
             }
-        }
+        },
     }
 
     json_schema_response = {
@@ -766,46 +745,46 @@ def test_response_translation_propertyPattern_with_ref():
         "type": "object",
         "additionalProperties": False,
         "properties": {
-            "statusCode": {
-                "type": "number"
-            },
+            "statusCode": {"type": "number"},
             "body": {
                 "type": "object",
                 "patternProperties": {
-                    "^\d+$": {
+                    "^\\d+$": {
                         "type": "object",
                         "properties": {
                             "example_key1": {
                                 "description": "explaining example_key1",
-                                "type": "string"
+                                "type": "string",
                             },
-                            "example_key2": {
-                                "type": "integer"
-                            }
-                        }
+                            "example_key2": {"type": "integer"},
+                        },
                     }
                 },
-                "additionalProperties": False
+                "additionalProperties": False,
             },
             "headers": {
                 "type": "object",
-                "properties": {
-                    "content-type": {
+                "additionalProperties": True,
+                "patternProperties": {
+                    "[cC]ontent-[tT]ype": {
                         "type": "string",
-                        "enum": [
-                            "application/json"
-                        ]
+                        "enum": ["application/json"],
                     }
-                }
-            }
+                },
+            },
         },
-        "required": [
-            "statusCode",
-            "headers",
-            "body"
-        ]
+        "required": ["statusCode", "headers", "body"],
     }
 
     from aws_schema.openAPI_converter import _convert_response
-    assert _convert_response(open_api_path, open_api_method, open_api_statusCode,
-                             open_api_response, components) == json_schema_response
+
+    assert (
+        _convert_response(
+            open_api_path,
+            open_api_method,
+            open_api_statusCode,
+            open_api_response,
+            components,
+        )
+        == json_schema_response
+    )
